#!/usr/bin/env python
import os
import os.path
import unittest

import pexpect
import pexpect.replwrap

from .test import BASE_DIR, TEST_DIR, Shell, TestShellBase


@unittest.skip("tcsh is not supported. Enable this test manually if needed.")
class TestTcsh(TestShellBase, unittest.TestCase):
    expected_failures = [
        "test_unquoted_space",
        "test_quoted_space",
        "test_continuation",
        "test_parse_special_characters",
        "test_parse_special_characters_dollar",
        # Test case doesn't work under tcsh, could be fixed.
        "test_comp_point",
    ]

    def setUp(self):
        sh = Shell("tcsh")
        path = " ".join([os.path.join(BASE_DIR, "scripts"), TEST_DIR, "$path"])
        sh.run_command("set path = ({0})".format(path))
        sh.run_command("setenv PYTHONPATH {0}".format(BASE_DIR))
        # 'dummy' argument unused; checks multi-command registration works
        # by passing 'prog' as the second argument.
        output = sh.run_command("eval `register-python-argcomplete --shell tcsh dummy prog`")
        self.assertEqual(output, "")
        # Register a dummy completion with an external argcomplete script
        # to ensure this doesn't overwrite our previous registration.
        output = sh.run_command(
            "eval `register-python-argcomplete --shell tcsh dummy --external-argcomplete-script dummy`"
        )
        self.assertEqual(output, "")
        self.sh = sh

    def tearDown(self):
        # The shell wrapper is fragile; exactly which exception is raised
        # differs depending on environment.
        with self.assertRaises((pexpect.EOF, OSError)):
            self.sh.run_command("exit")
            self.sh.run_command("")


@unittest.skip("fish is not supported. Enable this test manually if needed.")
class TestFish(TestShellBase, unittest.TestCase):
    expected_failures = [
        "test_parse_special_characters",
        "test_comp_point",
    ]

    skipped = ["test_single_quotes_in_single_quotes", "test_parse_special_characters_dollar"]

    def setUp(self):
        sh = Shell("fish")
        path = " ".join([os.path.join(BASE_DIR, "scripts"), TEST_DIR, "$PATH"])
        sh.run_command("set -x PATH {0}".format(path))
        sh.run_command("set -x PYTHONPATH {0}".format(BASE_DIR))
        # 'dummy' argument unused; checks multi-command registration works
        # by passing 'prog' as the second argument.
        output = sh.run_command("register-python-argcomplete --shell fish dummy prog | source")
        self.assertEqual(output, "")
        # Register a dummy completion with an external argcomplete script
        # to ensure this doesn't overwrite our previous registration.
        output = sh.run_command(
            "register-python-argcomplete --shell fish dummy --external-argcomplete-script dummy | source"
        )
        self.assertEqual(output, "")
        self.sh = sh

    def tearDown(self):
        # The shell wrapper is fragile; exactly which exception is raised
        # differs depending on environment.
        with self.assertRaises((pexpect.EOF, OSError)):
            self.sh.run_command("exit")
            self.sh.run_command("")



import os

project = "argcomplete"
copyright = "Andrey Kislyuk and argcomplete contributors"
author = "Andrey Kislyuk"
version = ""
release = ""
language = "en"
master_doc = "index"
extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.viewcode",
    "sphinx.ext.intersphinx",
    "sphinx_copybutton",
    "sphinxext.opengraph",
]
source_suffix = [".rst", ".md"]
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]
pygments_style = "sphinx"
autodoc_member_order = "bysource"
autodoc_typehints = "description"
autodoc_typehints_description_target = "documented_params"
intersphinx_mapping = {
    "https://docs.python.org/3": None,
}
templates_path = [""]
ogp_site_url = "https://kislyuk.github.io/" + project

if "readthedocs.org" in os.getcwd().split("/"):
    with open("index.rst", "w") as fh:
        fh.write("Documentation for this project has moved to https://kislyuk.github.io/" + project)
else:
    html_theme = "furo"
    html_sidebars = {
        "**": [
            "sidebar/brand.html",
            "sidebar/search.html",
            "sidebar/scroll-start.html",
            "toc.html",
            "sidebar/scroll-end.html",
        ]
    }



# PYTHON_ARGCOMPLETE_OK
import argparse

import argcomplete


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("arg", choices=["arg"])
    argcomplete.autocomplete(parser)
    args = parser.parse_args()
    print(args.arg)


if __name__ == "__main__":
    main()



#!/usr/bin/env python

import glob

from setuptools import find_packages, setup

setup(
    url="https://github.com/kislyuk/argcomplete",
    packages=find_packages(exclude=["test", "test.*"]),
    scripts=glob.glob("scripts/*"),
    package_data={"argcomplete": ["bash_completion.d/_python-argcomplete", "py.typed"]},
    zip_safe=False,
    include_package_data=True,
    platforms=["MacOS X", "Posix"],
)



#!/usr/bin/env python
# PYTHON_ARGCOMPLETE_OK

import argparse
import pprint

import requests

import argcomplete


def github_org_members(prefix, parsed_args, **kwargs):
    resource = "https://api.github.com/orgs/{org}/members".format(org=parsed_args.organization)
    return (member["login"] for member in requests.get(resource).json() if member["login"].startswith(prefix))


parser = argparse.ArgumentParser()
parser.add_argument("--organization", help="GitHub organization")
parser.add_argument("--member", help="GitHub member").completer = github_org_members

argcomplete.autocomplete(parser)
args = parser.parse_args()

pprint.pprint(requests.get("https://api.github.com/users/{m}".format(m=args.member)).json())
